/** @file
 * @brief TZO Service class header. This class represents the TZO service.
 *
 *
 *
 * @copyright Intra2net AG
 * @license GPLv2
*/

#ifndef ServiceTzo_H
#define ServiceTzo_H

#include "service.h"
#include "logger.h"
#include "httphelper.h"

#include <boost/shared_ptr.hpp>
#include <string>


class ServiceTzo : public Service
{

private:

    friend class boost::serialization::access;
    template<class Archive>
    void serialize(Archive & ar, const unsigned int version)
    {
        ar & boost::serialization::base_object<Service>(*this);
    }

    std::string BaseUrl;

    HTTPHelper::Ptr HTTPHelp;

    std::string assemble_base_url(const std::string& fqhn, const std::string& username, const std::string& password) const;

public:

    typedef boost::shared_ptr<ServiceTzo> Ptr;

    ServiceTzo();

    ServiceTzo(const std::string& _protocol, const std::string& _hostname, const std::string& _login, const std::string& _password, const Logger::Ptr& _logger, const int _update_interval, const int _max_updates_within_interval, const int dns_cache_ttl, const std::string& proxy, const int proxy_port);

    ~ServiceTzo();

    int perform_update(const std::string& ip);
};

#endif
